/*
Szymon Rusinkiewicz
Princeton University

imageio_test.c
Simple test of the imageio functionality
*/

#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include "imageio.h"


/* Helper function: returns distance from (x,y) to center of an image of
   size (w,h), scaled such that corners are 1 */
inline float dist2cent(int x, int y, int w, int h)
{
	float dx = (0.5f * w) - (x + 0.5f);
	float dy = (0.5f * h) - (y + 0.5f);
	float cx = (0.5f * w) - 0.5f;
	float cy = (0.5f * h) - 0.5f;
	return sqrt((dx*dx + dy*dy) / (cx*cx + cy*cy));
}


/* Main function */
int main(int argc, char *argv[])
{
	const char *infilename, *outfilename;
	Im *im;
	int x, y;

	if (argc < 3) {
		fprintf(stderr, "Usage: %s in.png out.png\n", argv[0]);
		exit(1);
	}
	infilename = argv[1];
	outfilename = argv[2];

	/* Read an image */
	im = Im_read(infilename);
	if (!im)
		exit(1);

	printf("Read an image of size %d x %d\n", im->w, im->h);

	/* Transform image - apply a vignetting filter */
	for (y = 0; y < im->h; y++) {
		for (x = 0; x < im->w; x++) {
			Color *pixel = Im_pixel(im, x, y);
			float scale = 1.0f - dist2cent(x, y, im->w, im->h);
			pixel->r = (unsigned char) (scale * pixel->r);
			pixel->g = (unsigned char) (scale * pixel->g);
			pixel->b = (unsigned char) (scale * pixel->b);
		}
	}

	/* Write image back out */
	if (!Im_write(im, outfilename))
		exit(1);

	exit(0);
}
